#
# spec file for package mc
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mc
Version:        4.8.27
Release:        lp155.4.10
Summary:        Midnight Commander
License:        GPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://midnight-commander.org/
Source0:        http://ftp.midnight-commander.org/mc-%{version}.tar.xz
Source1:        x11_browser
Source2:        %{name}.desktop
Source3:        %{name}.png
Source4:        cmake.syntax
Source6:        http://ftp.midnight-commander.org/%{name}-%{version}.sha256
Patch0:         mc-fix_lib_search_path.patch
Patch12:        mc-wrapper.patch
Patch16:        mc-esc-seq.patch
Patch20:        mc-f-keys.patch
Patch21:        mc-extfs-helpers-deb.patch
# add patch. bnc#856501
# http://www.midnight-commander.org/ticket/3128
Patch22:        mc-vfs-fish-deleted_source_file.patch
# changed mc-extfs-iso9660-xorriso.patch
# to reflect upstream fix
Patch23:        mc-extfs-iso9660-xorriso.patch
#Debian fixes
Patch32:        20_wrong_path_to_wrappers.patch
# PATCH-FIX-UPSTREAM mc-multi-press-f-keys.patch mc287 sbrabec@suse.cz - Fixed Esc + Numeral F-key emulation.
Patch41:        mc-multi-press-f-keys.patch
# Patches from Fedora
#Patch adding -fpie and -pie to compilation and linking of setuid binaries
Patch52:        mc-pie.patch
# mc-startup-timeout.patch mc3082 nadvornik@suse.cz - fix for long timeout on startup, bnc#824729
Patch60:        mc-startup-timeout.patch
Patch61:        mc-extd-misc.patch
Patch62:        mc-extd-video.patch
Patch63:        mc-extd-doc.patch
Patch64:        mc-extd-sound.patch
Patch69:        mc-extd-xdg.patch
Patch71:        mc-ext-audio.patch
Patch100:       xls2csv_update.patch
#jng!
Patch491:       jng01-prefs.diff
Patch492:       jng2523-unicode.diff
Provides:	%name(jng-config) = %version-%release
BuildRequires:  audiofile-devel
BuildRequires:  e2fsprogs-devel
BuildRequires:  gettext >= 0.18.1
BuildRequires:  glib2-devel >= 2.26.0
BuildRequires:  gpm-devel
BuildRequires:  libssh2-devel
BuildRequires:  libtool
BuildRequires:  readline-devel
BuildRequires:  slang-devel
BuildRequires:  update-desktop-files
BuildRequires:  xdg-utils
BuildRequires:  xorg-x11-devel
BuildRequires:  xz
Requires(pre):  permissions
Recommends:     %{name}-lang = %{version}
Recommends:     mkisofs
Recommends:     xorriso

%description
GNU Midnight Commander (also referred to as MC) is a user shell much
like the (in)famous Norton Commander with text-mode full-screen
interface. It can be run on the OS console, in xterm and other
terminal emulators.

GNU Midnight Commander allows you to manage files while making most of
your screen and giving you a clear representation of the filesystem, yet
it's simple enough to be run over a telnet or ssh session.

MC needs several other programs for its various extfs extensions, e.g.
isoinfo (from mkisofs) or xorriso for the iso:// extension.

%lang_package

%prep
echo "`grep %{name}-%{version}.tar.xz %{SOURCE6} | head -n1 | cut -c1-64`  %{SOURCE0}" | sha256sum -c
%setup -q
%patch0
%patch61
%patch62
%patch63
%patch64
%patch69
%patch71
%patch12 -p1
%patch16
%patch20
%patch21
%patch22 -p1
%patch23
%patch32
%patch41 -p1
%patch52 -p1
%patch60 -p1
%patch100 -p1

#jng
%patch -P 491 -P 492 -p1

%build
autoreconf -fvi
%define warn_flags -W -Wall -Wstrict-prototypes -Wpointer-arith -Wformat-security -Wno-unused-parameter
export CFLAGS="%{optflags} %{warn_flags}"

export X11_WWW="%{_datadir}/mc/x11_browser"

export PYTHON=%{_bindir}/python3

%configure \
    --localstatedir=%{_localstatedir}/lib \
    --enable-charset \
    --enable-vfs-smb --with-smb-configdir=%{_sysconfdir}/samba \
    --disable-vfs-fish

%make_build

%install
%make_install

# clean up this setuid problem for now
chmod 755 %{buildroot}/%{_libexecdir}/mc/cons.saver

install -m 0644 %{SOURCE4} %{buildroot}%{_datadir}/mc/syntax/

#install the shell functions for bourne shell and csh
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
ln -fs -t %{buildroot}%{_sysconfdir}/profile.d %{_datadir}/mc/mc.{,c}sh
#support script for calling available GUI webbrosers
install -m 755 %{SOURCE1} %{buildroot}%{_datadir}/mc/
install -D -m 644 %{SOURCE3} %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -D -m 644 %{SOURCE3} %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png

for f in ext.d/misc.sh ext.d/sound.sh ext.d/video.sh \
    extfs.d/gitfs+ extfs.d/uace extfs.d/uarc ;
do
    sed -i -e '1s@bin/sh@bin/bash@' "%{buildroot}%{_libexecdir}/mc/${f}"
done

%suse_update_desktop_file -i %{name} System FileManager
# Remove not supported language
rm -rf  %{buildroot}%{_datadir}/locale/be@tarask

%find_lang %{name}

%post
%if 0%{?suse_version} >= 1140
%set_permissions %{_libexecdir}/mc/cons.saver
%else
%run_permissions
%endif

%verifyscript
%verify_permissions -e %{_libexecdir}/mc/cons.saver

%files
%doc ABOUT-NLS NEWS README
%license COPYING
%config %{_sysconfdir}/profile.d/*
%{_bindir}/mc*
%dir %{_sysconfdir}/mc/
%config %{_sysconfdir}/mc/filehighlight.ini
%config %{_sysconfdir}/mc/sfs.ini
%config %{_sysconfdir}/mc/mc.menu
%config %{_sysconfdir}/mc/mc.ext
%config %{_sysconfdir}/mc/mcedit.menu
%config %{_sysconfdir}/mc/mc.keymap
%config %{_sysconfdir}/mc/mc.default.keymap
%config %{_sysconfdir}/mc/mc.emacs.keymap
%config %{_sysconfdir}/mc/edit.indent.rc
%dir %{_libexecdir}/mc
%{_libexecdir}/mc/ext.d
%{_libexecdir}/mc/extfs.d
%verify(not mode) %{_libexecdir}/mc/cons.saver
%{_mandir}/man1/*
%exclude %{_mandir}/*/man1/*
%{_datadir}/mc
%{_datadir}/mc/syntax/Syntax
%{_datadir}/mc/mc.charsets
%{_datadir}/mc/mc.lib
%{_datadir}/mc/hints/mc.hint
%exclude %{_datadir}/mc/hints/mc.hint.*
%{_datadir}/mc/help/mc.hlp
%exclude %{_datadir}/mc/help/mc.hlp.*
%exclude %{_datadir}/locale/*/LC_MESSAGES/mc.mo

%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/32x32
%dir %{_datadir}/icons/hicolor/32x32/apps
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png

%files lang -f %{name}.lang
%if 0%{?suse_version} < 1140 || 0%{?sles_version} && 0%{?sles_version} <= 11
%lang(sv) %dir %{_datadir}/locale/sv_SE
%lang(sv) %dir %{_datadir}/locale/sv_SE/LC_MESSAGES
%lang(szl) %dir %{_datadir}/locale/szl
%lang(szl) %dir %{_datadir}/locale/szl/LC_MESSAGES
%endif

%lang(hu) %dir %{_mandir}/hu/
%lang(hu) %dir %{_mandir}/hu/man1/
%lang(hu) %{_mandir}/hu/man1/mc.1.gz

%lang(pl) %dir %{_mandir}/pl/
%lang(pl) %dir %{_mandir}/pl/man1/
%lang(pl) %{_mandir}/pl/man1/mc.1.gz

%lang(sr) %dir %{_mandir}/sr/
%lang(sr) %dir %{_mandir}/sr/man1/
%lang(sr) %{_mandir}/sr/man1/mc.1.gz

%lang(cs) %doc %{_datadir}/mc/*/mc.*.cs
%lang(es) %doc %{_datadir}/mc/*/mc.*.es
%lang(hu) %doc %{_datadir}/mc/*/mc.*.hu
%lang(it) %doc %{_datadir}/mc/*/mc.*.it
%lang(nl) %doc %{_datadir}/mc/*/mc.*.nl
%lang(pl) %doc %{_datadir}/mc/*/mc.*.pl
%lang(ru) %doc %{_datadir}/mc/*/mc.*.ru
%lang(sr) %doc %{_datadir}/mc/*/mc.*.sr
%lang(uk) %doc %{_datadir}/mc/*/mc.*.uk
%lang(zh) %doc %{_datadir}/mc/*/mc.*.zh

%changelog
* Thu Sep  2 2021 ecsos <ecsos@opensuse.org>
- Midnight Commander 4.8.27:
  * Core
  - Minimal version of Autoconf is 2.64 (#3603)
  - Minimal version of Automake is 1.12 (#3986)
  - Minimal version of Gettext is 0.18.2 (#3603)
  - Minimal version of libssh2 is 1.2.8 (#4259)
  - Reimplement version detection (#3603, #4249)
  - Significantly reduce rebuilt time after version change (#2252, #4266)
  - Drop automatic migration of configuration from ~/.mc to XDG-based directories (#3682)
  - zsh: support custom configuration file: ~/.local/share/mc/.zshrc (#4203)
  - Widgets: implement WST_VISIBLE state to show/hide widgets (#2919)
  - Find File: add Follow symlinks option (#2020)
  * VFS
  - extfs: support unrar-6 (#4154)
  - extfs: support official 7z binary (7zz) (#4239)
  - ftpfs: apply file list parser from lftp project (#2841, #3174)
  * Editor
  - Word completion: get candidates from all open files (#4160)
  - etags: get rid of hardcoded list length and window width (#4132)
  - Update syntax files:
  - python (#4140)
  - Add syntax highlighting:
  - Verilog and SystemVerilog? header files (#4215)
  - JSON (#4250)
  - openrc-run scripts (#4246)
  * Viewer
  * Diff viewer
  * Misc
  - Code clean up (#4179, #4173, #4269)
  - Filehighlight of c++ and h++ files as sources (#4194)
  - Filehighlight of JSON files as documents (#4250)
  - Support of alacritty terminal emulator (​https://github.com/alacritty/alacritty) (#4248)
  - Support of foot terminal emulator (​https://codeberg.org/dnkl/foot) (#4251)
  - Support of (alt+)shift+arrow keys in st terminal emulator (st.suckless.org) (#4267)
  - Mouse support in screen: don't check  variable (#4233)
  - mc.ext: support fb2 e-books (#4167)
  - ext.d: use mediainfo to view info about various media files (#4167)
  - Remove OS/distro-specific package-related stuff from source tree (#4217)
  * Fixes
  - FTBFS against NCurses on OS X 10.9.5 (#4181)
  - Segfault on dialog before panels get visible (#4244)
  - Crash if shadow is out of screen (build against NCurses) (#4192)
  - Crash in search (#4222)
  - Crash on startup with enabled subshell in FreeBSD (workaround) (#4213)
  - Hang on start randomly with zsh as subshell (#4198)
  - If command line is invisible it's partially displayed (#4182)
  - Broken handling of zip archives (#4180, #4183)
  - Broken handling of jar files as zip archives (#4223)
  - Timestamps of symlinks, sockets, fifos, etc are not preserved after copy/move (#3985)
  - %%view action in the user menu doesn't work on no-exec filesystem (#4242)
  - Hardlinks are not colored by file type or extension (#3375)
  - mcedit: silent macro makes terminal disrupted (#4171)
  - mcedit: disrupting of TAGS file path (#4207)
  - vfs: unable to browse compressed tar archives (#4191)
  - sftpfs vfs: CVE-2021-36370: server fingerprint isn't verified
    (discovered by AUT-milCERT during an audit of open source software) (#4259)
  - ftpfs vfs: month of file is always January (#4260)
  - Tests: log files are written by libcheck and automake simultaneously (#3986)
- Rebase mc-ext-audio.patch.
- Rebase mc-extd-sound.patch.
* Sun Mar 14 2021 Andreas Stieger <andreas.stieger@gmx.de>
- Midnight Commander 4.8.26:
  * Support file names of any length
  * Implement persistent command line buffer for subshell
    (bash >= 4, zsh and fish are supported)
  * Implement shadows of dialog windows and menus
  * Allow running clipboard commands if DISPLAY is not set
  * Add support of "alacritty", "tmux", and "tmux-256color" terminals
  * VFS: Support wim archive format (using wimtools)
  * VFS: Support pak archive format (using unar)
  * Editor: Add Swift syntax highlighting
  * Various bug fixes
* Mon Jul 27 2020 Andre C. Barros <andre.cbarros@yahoo.com>
- Update to 4.8.25
  * Avoid subshell warning for standalone mcedit/mcview/mcdiffview run from mc
  * Implement chattr command (change ext{2,3,4}fs extended attributes)
  * New syntax highlighting: Kotlin and ino
  * File highlighting updates
  * Lots of other fixes
- Updated mc-ext-audio.patch
- Updated mc-extd-sound.patch
- Removed mc-rpm.patch
* Tue Mar 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.8.24
  * Implement the file edit and view history
  * sftpfs: support keyborad interactive authentication
  * add yabasic (Yet Another BASIC) syntax highlighting
  * File highlighting updates
  * New skins
  * Lots of other fixes
- Remove sftp_interactive_password.patch
- Remove mc-no-common.patch
* Wed Jan 15 2020 Adam Majer <adam.majer@suse.de>
- mc-no-common.patch: fix compilation on Tumbleweed (bsc#1160401)
* Thu Aug  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use python3 instead of python as we do not need to depend on
  python2
- Format with spec-cleaner
- update to 4.8.23:
  * Modify "File exists" query dialog (#3935):
  * Speed up of large directory structures delete (#3958)
  * Support key binding for menu (#212)
  * Syntax updates:
    + shell (#3981)
    + ebuild (#3988)
    + RPM spec (#3991)
  * Code cleanup (#3955)
  * Use Geeqie (a fork of GQview) as main image viewer, fallback to GQview (#3962)
  * various small fixes
- Refresh patches:
  * mc-multi-press-f-keys.patch
  * sftp_interactive_password.patch
* Tue Jan 15 2019 adam.majer@suse.de
- update to 4.8.22
  * Core
  - Support BTRFS's file clone operation
  - Find file: show pattern and content in the results window title
  - Find file: remember state (empty or not) of Content field
  - Improve support IBM i
  - Improve handling of hard link creation errors
  - Support user-defined prompt in the Fish subshell
  * VFS - sftp: preserve atime and mtime (#3917)
  * Editor
  - man page cleanup (#3918)
  - syntax:
    PHP - highlight keyword 'null' (#3920)
    Meson - initial implementation (#3940)
  * Misc
  - ext.d: use MPV as a fallback for mplayer -identify (#3919)
  - ext.d: improve recognition of MS Office formats (#3929)
  * Fixes
  - "Cannot create target file" when target has backslash space
    in the name (#3923)
  - Quiet single file overwrite (#3908)
  - Show error message for each not-installed program when view
    documents in MS Word and Excel formats (#3926)
  - Crash when trying some sftp connections (#3937)
  - Crash when return to filemanager from subshell (#3943)
- mc-extd-doc.patch: refreshed
- mc-extd-video.patch: refreshed
- mc-vfs-fish-deleted_source_file.patch: refreshed
- xls2csv_update.patch: refreshed
* Tue Jun 26 2018 adam.majer@suse.de
- sftp_interactive_password.patch: Fixes logins to remote SSH
  sessions where only Keyboard-Interactive password is available
  and tunneled password is disabled (bsc#1098235)
- mc-rpmlintrc: removed
* Tue Jun  5 2018 ecsos@opensuse.org
- update to 4.8.21
  * * Core
  * Cancel Chmod/Chown/Advanced chown operation for large group of files when operation is not permitted (#3850)
  * Mouse support in the "Advanced chown" dialog window (#3148)
  * File highlighting by extension is case insensitive by default (#1620)
  * Safe file overwrite (#3913)
  * * VFS
  * Support zstd compression format (#3906)
  * * Editor
  * Syntax:
  - Rust support (#3884)
  - JavaScript modules support (#3890)
  - Improve Markdown support (#3893)
  * * Viewer
  * * Diff viewer
  * * Misc
  * Add JavaScript module support to filehighlight.ini (MidnightCommander/mc#132)
  * Add Excel xlsx file format support to mc.ext.in (MidnightCommander/mc#135)
  * i18n of argument type names in --help blocks (#3879)
  * Code cleanup: (#3857, #3914)
  * * Fixes
  * Fail to link to ncurses built as two libraries: ncurses+tinfo (#3880)
  * Garbage in displaying of summary of file sizes for selected files (#3883)
  * "Compute totals" unnecessarily done for moves (#3149, #3908)
  * mc.ext: allow Java class files to be viewed even if JAD isn't on PATH (MidnightCommander/mc#134)
  * mcedit: broken extended key mode (#3897)
  * mcedit doesn't save all opened files (#3898)
  * extfs: sftps: -31 SFTP Protocol Error when transferring file
    (#3406, bsc#1119302)
  * extfs: rpm: truncated script content in the viewer (#3865)
  * extfs: rpm helper misses CONFLICTS field (#3789)
* Fri Apr 13 2018 adam.majer@suse.de
- Remove some unused BuildRequires, enabling building on SLE-15
- Drop fdupes usage as difference is only 1 file smaller than 1kB.
* Tue Apr 10 2018 adam.majer@suse.de
- xls2csv_update.patch: fix mc to call xls2csv correctly
  (bsc#1087708)
* Tue Nov 28 2017 ecsos@opensuse.org
- Update to Version 4.8.20
  * * Core
  * Rename key bindings:
  - [main].PanelListingSwitch -> [panel].CycleListingFormat
  - [main].PanelListingChange -> [main].SetupListingFormat
  * Speed up of UTF-8 normalization for frequent cases (#3616)
  * * VFS
  * extfs helpers tester:
  - diff of failed tests is now included in output to ease bug reporting (#3784)
  * * Editor
  * Syntax:
  - ES2015 support (#3793)
  - TypeScript support (#3794)
  - Ada 95 updates (#3804)
  - Apache Hive QL support (#3828)
  - SQL & PHP keyword updates (MidnightCommander/mc#129)
  - Simplification of case insensitive file name patterns in /usr/share/mc/syntax/Syntax file (#3829)
  - Markdown (initial support) (#3864)
  - Protocol Buffers and gRPC support (#3868)
  * Add %%c (cursor offset from BOF) support for user menu macros (#3867)
  * * Viewer
  * * Diff viewer
  * * Misc
  * Unify curses initialization for various curses implementations (#3697)
  * Highlight txz extension as archive like tgz, etc. (#3782)
  * Add new media extensions to filehighlight.ini (#3834)
  * * Fixes
  * Wrong --help message for mcview, mcedit and mcdiff (#3805)
  * Compression from menu broken due to bad quoting (#3840)
  * --with-homedir gives "yes" as config directory (#3836)
  * External panelize: opening a file with an absolute path fails (#2942)
  * Filter isn't cleared when entering empty string (#3813)
  * Panelization is not kept while switching panel listing mode (#3810)
  * Cannot tab out of a QuickView panel (#3815)
  * Cannot use the F10 key in a QuickView panel (#3816)
  * Wromg INPUT_COMPLETE_CD flag handling in the QuickDialog? engine (#3870)
  * mcview: file interpreted as latin1 instead of utf8 (#3783)
  * mcview: incomplete read of filtering data (#3817)
  * mcview: search doesn't grow file as much as needed (#3819, #3855)
  * mcview: goto doesn't grow file as much as needed (#3826)
  * mcview: quick view panel: crash on slow startup while switching panel mode (#3846)
  * mcedit: fix broken encoding into UTF-8 for 8-bit displays (#3843)
  * mcedit: incorrect %%f macro substitution in the user menu (#3861)
  * man pages: wrong paths of mc.hint and mc.hlp (#3806)
  * subshell: fix broken tcsh 6.20+ cd escaping (#3852)
  * VFS: incremental tar doesn't contain empty directories (#2297)
  * VFS: incremental tar: wrong directories owner for tar --numeric-owner -g (#3709)
  * VFS: timestamps not being preserved due to uninitialized struct stat st_[acm]tim.tv_nsec (#3821)
  * VFS: ftp: can't retrieve password from .netrc when user is in URL (#3869)
  * VFS: tests: locale issue causing helpers using 'sort' to fail (#3787)
  * VFS: tests: unportable 'echo' use causing one rpm helper test to fail (#3786)
  * Spelling errors in the manual page (#3839)
* Mon Mar  6 2017 dnh@opensuse.org
- Update to Version 4.8.19
  * * Core
  * Replace $MC_HOME with $MC_PROFILE_ROOT (#3684)
  * Allow rebind TAB key to change panel (#3672)
  * Support for True Color (16 millions colors) (#3145)
  * Color aliases in skin files (#3711)
  * * VFS
  * Support timestamps with nanosecond precision for copy/move operations (#3575)
  * Introduce EXTFS helpers tester (#3730, #3744, #3752, #3753, #3751)
  * Teach u7z to parse archive listings w/o sizes and/or dates (#2707)
  * Teach rpm helper about transaction scripts (#3750)
  * Fix hp48, uace & uarc extfs which used an obsolete date format (#3729, #3747)
  * * Editor
  * Syntax:
  - updates of HTML and ebuild highlighting
  - highlight *.t (Perl test) files as Perl scripts
  - disassociate .cl file extension from LISP syntax (#3691)
  * Add syntax highlighting:
  - OpenCL (#3690)
  - OpenShadingLanguage (#3762)
  - R
  - YAML (#3293)
  * * Misc
  * Code cleanup (#3693, #3703, #3721, #3763)
  * Add true color skins: 'Four seasons' (#3724)
  * Activate `--enable-tests` by default if `check` is found (#3708)
  * Added new skin: YADT (MidnightCommander/mc#115)
  * * Fixes
  * Segfault on switching left panel to Info (#3700)
  * Broken compatibility with ncurses (#3697)
  * Setting MC_HOME makes mc ignore ~/.bashrc (#3684)
  * mc_tmpdir() use a buffer of only 64 characters (#3736)
  * Some bugs in the parsing of hexadecimal search patterns (#3694)
  * Hexadecimal search fails on binary data (#3589)
  * Broken file list resorting on double click on panel header line (#3715)
  * Wrong dialog resizing and positioning (#3714, #3723)
  * Widget's 'disabled' status is not toggled immediately (#3716)
  * Last item of 'Options/Layout/Horizontal' radiobuttons remains highlighted (#3717)
  * 'Options/Layout/Equal split' checkbox gets reverted (#3718)
  * Panels: cannot show more than one "column" in user defined listing mode (#3757)
  * Mix of MSG_NOTIFY and MSG_FOCUS messages (#3731)
  * skins: 'window-state-char' and 'window-close-char' are parsed as colors (#3710)
  * Pressing <right> and <left> in the hotlist dialog doesn't refresh it (#3775)
  * mcview: an error message about bad regexp isn't shown (#3720)
  * mcedit: fix etags filenames parsing (#3698)
  * mcedit: fix mouse active area for maximize / close buttons (#3774)
  * mcedit: frames (MDI interface) don't reflect the focus state (#3766)
  * mcedit: frames (MDI interface) sometimes obscure the buttonbar (#3760)
  * mcedit doesn't show search error messages when searching backwards (#3735)
  * help viewer: tab characters handled incorrectly (#3754)
  * VFS: incorrect zoo archive listing (#3696)
  * VFS: segfault in VFSs not setting block size in stat (#3749)
- removed obsolete 02_ignore_ftp_chmod_error.patch
  if ignore_ftp_chattr_errors=true (the default?) in
  ~/.config/mc/ini, errors are ignored anyway, and if if set to false,
  the user get the error (e.g. permission denied). With the patch, the
  user never will see an error and wonder, why it's not working. It
  might have been, that this option has not worked in (much) older
  versions and the patch introduced because of this.
- removed obsolete 09_uzip_broken_528239.patch
  it is correctly detected during configure
- rebased mc-rpm.patch
* Mon Oct  3 2016 dnh@opensuse.org
- Update to Version 4.8.18
- Core
  * Alt-Enter, Ctrl-Enter and Ctrl-Shift-Enter shortcuts are bindable in file manager (#3075)
  * Internals:
  * Refactoring of widget subsystem (#2919, #3632)
- Editor
  * Add syntax highlighting:
  * GLSL (#3683)
  * CUDA (#3686)
- Misc
  * Code cleanup (#3641, #3652)
- Fixes
  * Build failure on FreeBSD (#3643)
  * Incompatibility with NetBSD curses (#3665)
  * Memory leaks (#3637)
  * Subshell output lost on window resize under tmux, GNU screen (#3639)
  * --with-subshell=optional does not work (#3642)
  * Backward search is not interruptible (#3648)
  * "Output lines" has no effect (#3655)
  * Wrong handling of mouse clicks in long listing mode (#3661)
  * Panelize resets marks on marked files in many cases (#3663)
  * Cannot change directory in the active panel in some cases (#3669)
  * Filtered View doesn't work (#3646, #3660)
  * mcedit: don't kill bookmarks when open file from "Find File" dialog (#3668)
  * man pages use "the MC" instead of "MC" (#3644)
* Mon May  9 2016 dnh@opensuse.org
- Update to 4.8.17:
  === Core ===
  * Minimal version of Gettext is 0.18.1 (#1885)
  * Optimization of copy/move operations (use adaptive buffer as in coreutils) (#2193)
  * Recognize csh as tcsh (#2742)
  * Сentered scrolling of file panel (#3130)
  * Internals:
  * Switch to new high-level mouse API (#3571)
  === VFS ===
  * FISH helpers: remove executable bit (#3610)
  === Editor ===
  * Improvements of syntax highlighting:
  * F90 (#3618)
  * Java (MidnightCommander/mc#95)
  === Misc ===
  * Code cleanup (#3598, #3607)
  * Install mc.keymap as a symlink to mc.default.keymap (#3609)
  * File highlight: add more common file formats
  === Fixes ===
  * Segfault due to incorrect value of SHELL environment variable (#3606)
  * Segfault when copying files under FreeBSD 9.3 (#3617)
  * Segfault when entering into some cpio archives (#3621)
  * Subshell output lost on window resize under tmux, GNU screen (#3639)
  * Subshell cursor position lost after window resizing (#3640)
  * Listbox no longer scrolls when dragging outside widget (#3559)
  * VFS: extfs: incorrect date parsing in unzip (#3622)
  * VFS: extfs: buffer overflow (#3605)
  * VFS: patchfs: syntax error (#3620)
  * VFS: fish: mistakes in ls Perl helper (#3611)
- remove upstreamed Patch99: mc-patchfs_lzip-syntax-error.patch
* Fri Apr  1 2016 dnh@opensuse.org
- Add no-brainer patch mc-patchfs_lzip-syntax-error.patch from upstream
  that fixes a syntax error in the patchfs helper script (bsc#972789).
* Mon Mar 14 2016 dnh@opensuse.org
- Update to 4.8.16:
  Core
    Support for ash + bugfixes for bash, fish (#2742)
    Find file: empty file name matches any file name (#3593)
    Find file: empty value of "Content" is used instead of "Search for content" checkbox to disable search for content (#3594)
    Listbox: don't wraparound on mouse scroll (#3554)
    Internals:
    Listbox: various fixups (#3569: #3562, #3563, #3565, #3161)
    Split MSG_ACTION into MSG_ACTION and MSG_NOTIFY (#3566)
  VFS
    Support lzip compression format (#2673, #1541)
    Support lz4 compression format (#3523)
    patchfs: support xz compression (#3443)
    Update uc1541 version (#3527)
    Add mc.ext patterns for initramfs / initrd (#3115)
  Editor
    Add golang syntax (MidnightCommander?/mc#84)
    Update Puppet syntax (MidnightCommander?/mc#86)
  Misc
    Code cleanup (#3555, #3547, #3587)
    Better subshell documentation (#3556)
    Fixes to the English man pages by Denys Vlasenko
  Fixes
    Insufficient quoting in mc.menu (#2947)
    Broken ./configure --without-internal-edit (#3601)
    Memory leaks (#3547, #3561, #3567, #3572)
    No preallocation if appending during file copy (#3577)
    Cannot set mini-format for "brief" listing type (#3588)
    Info panel: incorrect inode information in some cases (#3214)
    Info panel: wrong device name with symbolic link (#3412)
    Info panel: buffer overflow (#3582)
    Regression: match filename, not full path in mc.ext (#3578)
    Broken case insensitive search in non-unicode locale (#3491)
    Error message prefixed with no sense "0:" (#3269)
    mcedit: buffer overflow (#3579)
    mcedit: "Lower case selection" command in User Menu (#3586)
    mcedit: close on ctrl-g (#3557)
    mcview: "Not found" result isn't reported in some cases (#3543)
    VFS: isofs doesn't show .dotfiles (#3537)
    VFS: isofs: cannot copy file from iso when Joliet without RockRidge? is used (#2851)
    VFS: extfs/unzip: enter into zip file fails with "inconsistent extfs archive" (#3433)
    VFS: SFTP: various bugs (#3581)
    VFS: FISH: provide major/minor info for block/char devices (#3599)
    Bashism in gitfs+ extfs helper (#3379)
    Non-portable invocation of man (#3509)
    mc-wrapper leaves MC_USER set (#3550)
    Broken silent opening of files in background (#3574)
    Run identify on JPEGs even if exif is not installed (#3568)
- rebased a bunch of patches
* Mon Nov  9 2015 astieger@suse.com
- verify the sha256 hash during build
* Mon Nov  9 2015 pth@suse.de
- Tag .sha256 file as source.
* Mon Nov  9 2015 dnh@opensuse.org
- Update to 4.8.15:
  * Core:
    Minimal version of GLib is 2.26.0
    Use the PATH environment variable to search for the executable when opening pipe (#3444)
    Support more than 2 (up to 9) columns in file panel in brief mode (#3212)
    Clarify file sorting in "Unsorted" mode (#3496)
    WGroupbox: respect dialog's colors (#3468)
    Highlight find file's result in internal viewer (#3530)
  * VFS:
    s3 extfs vfs: bugfixes and improvements (#3470, #3502)
  * Editor:
    Add hidden option to choose full or base file name in the status line (#3445)
    Improvements of syntax highlighting:
    Lua (#3471)
    PKGBUILD (#3484)
  * Misc:
    Text alignment in Info panel (#3155)
    Select of menu file edit: change default button to "User" (#3493)
    Recognize .gmo files as well as .mo ones (#3422)
    Fix mc.pot comment tripping up Transifex and unportable inplace sed (#3479)
    A lot of code clean up (#3420, #3424, #3426, #3427, #3428, #3429, #3430, #3431, #3434, #3435, #3437, #3463, #3464, #3465, #3466, #3467, #3494, #3495, #3539)
    Documentation updates:
    Spanish man and help: Diff Viewer section and minor fixes (#3477)
    VFS garbage collection (#3472)
  * Fixes:
    Various memory leaks (#3438, #3439, #3440, #3457, #3458, #3459, #3460, #3461, #3462, #3475, #3520, #3521, #3522)
    Linux kernel-specific segfault on startup (#3441)
    Lost of Panelize contents in some cases (#3032, #3489, #3498, #3507)
    Wrong highlight of search result in case of "Regular expression" and "Whole words" (#3524)
    "Whole words" search works only in Normal mode (#3525)
    SFTP VFS: segfault (#3456)
    Segfault in "Find file" due to invalid UTF-8 sequences (#3449)
    Bash variable 'PROMPT_COMMAND' in pantheon-terminal (#3534)
- rebased mc-extd-xdg.patch against upstream changes
* Tue Mar 24 2015 astieger@suse.com
- GNU Midnight Commander 4.8.14:
  * Core:
    + Minimal version of GLib is 2.14.0
    + Add new panel binding "SelectExt" to select/unselect files
    with the same extension as the current file
    + Speed up of directory size calculation
    + Support of italic text
  * Editor:
    + New syntax highlighting support: puppet
  * Viewer:
    + Rewrite mcview's rendering and scrolling
    + Use VIEW_SELECTED_COLOR in plain mode
    + In QuickView panel, don't pass any chars to command line to
    avoid unexpected command execution
  * Misc:
    + Code cleanup
    + Bind poedit to Edit action for .po files
    + Better grammar mcedit user menu
  * Various bug fixes
* Sat Sep  6 2014 dnh@opensuse.org
- remove file mc-Syntax.cmake.patch / cmds in .spec
- remove file mc-vfs_fish_helpers_ls-formatstring.diff
  (extraneous patches seem to cause factory-auto to decline the submit)
  cf. e.g. https://build.opensuse.org/request/show/247789
* Fri Sep  5 2014 dnh@opensuse.org
- update to 4.8.13
  various bugfixes and minor improvements, see NEWS file for details
- comment out mc-Syntax.cmake.patch, fixed upstream, to be removed
* Wed Apr  2 2014 dnh@opensuse.org
- update to 4.8.12
- remove mc-vfs_fish_helpers_ls-formatstring.diff (fixed upstream)
- change mc-extfs-iso9660-xorriso.patch to work with upstream fix
* Sat Mar 15 2014 dnh@opensuse.org
- fix bug ("%%i" is not an appropriate format for off_t) in
  mc-vfs_fish_helpers_ls-formatstring.diff, thanks to andrew_b
  of upstream in mc-ticket:2983
* Sat Mar 15 2014 dnh@opensuse.org
- add mc-vfs_fish_helpers_ls-formatstring.diff
  fixing possible format-string attack via filename
  http://www.midnight-commander.org/ticket/2983
  until http://www.midnight-commander.org/ticket/3128
  is fixed, fish should stay disabled though!
* Thu Jan 30 2014 jengelh@inai.de
- Spec metadata update, remove redundant %%clean section,
  do parallel build with %%_smp_mflags
* Tue Jan 14 2014 dnh@opensuse.org
- add preliminary patch by Sebastian Siebert
  mc-vfs-fish-deleted_source_file.patch
  bnc#856501 and http://www.midnight-commander.org/ticket/3128
* Fri Jan 10 2014 dnh@opensuse.org
- disable the ssh/fish vfs due to
  http://www.midnight-commander.org/ticket/3128 and
  https://bugzilla.novell.com/show_bug.cgi?id=856501
- remove unneccessary build-dep on recode
* Wed Jan  1 2014 andreas.stieger@gmx.de
- update to 4.8.11:
  - Core
  * Live update of panels size when editing layout
  * Support "Compute totals" option in move file operation
  - VFS
  * rpm extfs
  - show dependency version
  - support tar payload
  - improve support for EPOCH tag
  - add support for PREINPROG/POSTINPROG/PREUNPROG/POSTUNPROG,
    VERIFYSCRIPTPROG and TRIGGERSCRIPTS/TRIGGERSCRIPTPROG tags
  - Editor
  * Support "bracketed paste mode" of xterm
  * Clarify Java syntax highlighting
  - Misc
  * Print warnings about unknown '--with-' / '--enable-' configure options
  * Code cleanup and refactoring
  - Fixes:
  * Segfault while moving files
  * Broken handling of mc command line arguments
  * Copy/move doesn't work if num_history_items_recorded=0
  * No subdir path completion in current dir, if stub is not starting with './'
  * Deprecated "find -perm +xxx" syntax is used
  * Home, End, Shift-Fn keys don't work in tmux
  * Improper [en|dis]abling of layout dialog split adjustment buttons
  * Bogus strings in 'Confirmation' config dialog
  * "Configure options" first entry not highlighted
  * "Setup saved to ~/.config/mc/ini" message is misleading
  * Typo in mc.lib: "less=%%filename +%%linenog" instead of "+%%lineno"
  * Wrong order of filename and line number for external editor
  * mcedit: tabs are lost when text is pasted
  * mcedit: question on large file treats Escape as Yes
  * Broken case-sensitive search in editor/viewer/diffviewer
  * Changes to files in nested .zip archives are lost
  * Incorrect handling of filenames with spaces with unrar v5
  * iso9660 VFS: filenames truncating in ISO file listing
  * vfs_path_from_str_flags() doesn't support VPF_STRIP_HOME
  * Bright colors are used as background colors in 16-color skins
  * Various defects in documentation
- removed patches:
  * mc-extfs-helpers-urar.patch, committed upstream
- modified patches:
  * mc-extfs-iso9660-xorriso.patch, adjust for upstream change
  * mc-multi-press-f-keys.patch, remove fuzz
  * mc-rpm.patch, adjust for upstream change in context
* Thu Dec 12 2013 dnh@opensuse.org
- fix the iso9660 some more and fall back from xorriso to isoinfo as
  xorriso fails on many DVD-iso files (well, that's UDF actually ..)
* Thu Dec 12 2013 dnh@opensuse.org
- add mc-extfs-iso9660-xorriso.patch
  fixing iso9660 extfs directory handling using xorriso
  see http://www.midnight-commander.org/ticket/3122
* Thu Nov 28 2013 dnh@opensuse.org
- Reimplementation of mcrar5fs_list in vfs/extfs/helpers/urar using
  'unrar vt' fixing the "trailing space" problem with 'unrar [lv]'
  closing http://www.midnight-commander.org/ticket/3073 and bnc#849082
* Mon Nov 25 2013 dnh@opensuse.org
- What a ghastly %%description ... Where'd that come from? ;) Fixed
  with text from the README and a little added mention of Norton Cmdr
* Mon Nov 25 2013 dnh@opensuse.org
- What's with those "trailing spaces" for filenames with length <13?
* Mon Nov 25 2013 dnh@opensuse.org
- fix the urar patch (add trailing whitespace) (thanks to D. Werner again)
* Sat Nov 23 2013 dnh@opensuse.org
- fix the urar patch (thanks to D. Werner again)
* Sat Nov 23 2013 dnh@opensuse.org
- fix SLE* %%post scriptlet error (%%set_permissions not available)
* Fri Nov 22 2013 dnh@opensuse.org
- make urar-helper patch portable (tested with busybox awk)
* Fri Nov 15 2013 dnh@opensuse.org
- four argument ("seps") gawk split() is new in 4.0.0, so explicitly
  require a gawk new enough
* Tue Nov 12 2013 dnh@opensuse.org
- add mc-extfs-helpers-urar.patch to fix urar extfs failing on files
  with spaces when unrar5 is used (bnc#849082). Thanks to D. Werner
  for finding the problem and proposing the fix.
* Mon Sep 30 2013 sbrabec@suse.cz
- Fix invalid mc.png (IDAT TFB error).
* Fri Sep 27 2013 nadvornik@suse.com
- mc-startup-timeout.patch: reduce the timeout when a dns server does
  not respond (bnc#824729)
* Fri Aug 23 2013 dnh@opensuse.org
- update to 4.8.10
- remove patch90 mc-bf3034-zip_in_tar.diff, fixed upstream
- remove patch91 mc-bf3040-mcedit_fd_leak.diff, fixed upstream
- more bugfixes: #3041, #3043, #3047, #2713, #3036
  see https://www.midnight-commander.org/ticket/<BUGNO>
- add libssh2 for sftp
* Thu Jul 18 2013 subchaser1@gmail.com
- most annoying bug fixes imported from upcomming 4.8.10
  * add mc-bf3034-zip_in_tar.diff: Cannot enter into zip archive
    in tar one (mc#3034)
  * add mc-bf3034-editor-fd-leak.diff: file descriptor leak in
    mcedit (mc#3040)
* Wed Jul 17 2013 subchaser1@gmail.com
- Update to new upstream release 4.8.9
  * extfs: support unrar-5
  * extfs: use xorriso (if exists) for writing into ISO images
  * extfs: display additional info while vieweing .iso files
    with F3
  * mcedit: support unlimited file size
- The changes since 4.8.1.7 are to numerous to list here,
  please read the file /usr/share/doc/packages/mc/NEWS for
  a complete list
- modify mc-multi-press-f-keys.patch: adopted for changes in
  sources
- modify mc-esc-seq.patch: adopted for changes in sources
- modify mc-rpm.patch: adopted for changes in sources
- modify mc-Syntax.cmake.patch: added .cmake file ext for cmake
  syntax highlighting
- changes made for ext.d hanlers
  * add mc-ext-audio.patch: view action added for all audio files
  * add mc-extd-sound.patch: implement old functionality
  * add mc-extd-video.patch: implement old functionality
  * remove mc-apps-mediainfo.patch: implementation is moved to
    mc-extd-sound.patch and mc-extd-video.patch
  * add mc-extd-misc.patch: implement old functionality
  * remove mc-apps-torrent.patch: moved to mc-extd-misc.patch
  * add mc-extd-doc.patch: use elinks only when installed
  * remove mc-word_docs.patch: Word docs now handled correctly
    using xdg-open utility
  * add mc-extd-xdg.patch: use xdg-open in X11 sessions only
  * remove mc-apps.patch: re-implemented in patches for ext.d
    handlers
  * remove mc-extensions.patch: implementations is moved to
    sound/video/doc patches for ext.d handlers
  * remove mc-x11browser.diff: obsolated, implemented in ext.d/web.sh
- remove mc-palmsupport.patch: Palm Pilot support removed from
  system-wide menu file
* Thu Mar  7 2013 subchaser1@gmail.com
- Update to 4.8.1.7 (latest stable release):
  The changes since 4.8.1.4 are to numerous to list here.
  Please see the file NEWS in the documentation for a complete list.
* Mon Jul 23 2012 subchaser1@gmail.com
- extfs deb helper: execute uar helper as fall-back if deb utilities is not installed
* Sat Jul 21 2012 subchaser1@gmail.com
- fixed deb file extension support, use dpkg-deb from 'deb' package
  if installed
* Sat Jul 21 2012 subchaser1@gmail.com
  Updated to version 4.8.1.4
- Misc
  * Tweak and cleanup of code in case of --disable-charset option usage (#2827)
  * File extension support:
  - .gem - rubygems (#2797)
  - .cpio.xz - compressed cpio archives (#2798)
- Fixes
  * Build failure on FreeBSD 6 (#2808)
  * src/filemanager/filegui.c does not compile on Solaris due to missing macros (#2825)
  * Loss of data on copy to full partition (#2829)
  * Misinterpretation of dirs as command line arguments (#2783, #2805)
  * Number of panelized files was limited to 127 (#2813)
  * URL with port was stored wrong in history (#2833)
  * Can't find 00 (zeroes) in patterns in hex search (#2795)
  * Hotkey conflicts in 'Search' dialog (#2843)
  * Garbage directory listing in ftpfs (#2800)
  * Incomplete sand256 skin (#2807)
  * mcedit scripts are installed as data files (#1437)
  * Tests failure on PowerPC,S390,S390x (#2804)
  * Fail to compile if --without-vfs configure option specified (#2834)
  * do_panel_cd: FTBFS with --enable-tests on [kfreebsd-i386,kfreebsd-amd64,ia64,armhf] (#2803)
* Mon May 28 2012 subchaser1@gmail.com
- cmake syntax revisited
* Thu May 10 2012 subchaser1@gmail.com
- Samba VFS restored, fixed path to smb.conf
* Thu Apr 26 2012 subchaser1@gmail.com
- Update to 4.8.1.3 (regression fix release):
  This release fixes two regressions in the just-released
  previous stable version: a crash in the chown and symlink dialogs,
  and an erroneous error popup when entering a tar archive.
* Mon Apr 23 2012 subchaser1@gmail.com
- Update to 4.8.1.2 (bugfix release):
  The changes since 4.8.1.1 are to numerous to list here.
  Please see the file NEWS in the documentation for a complete list.
- mc-mcviewsegfault.patch removed, fixed in changeset 95fdd2
* Wed Apr  4 2012 subchaser1@gmail.com
- .torrent extension viewer fixed
* Sat Mar 24 2012 subchaser1@gmail.com
- x11_browser issues fixed
  * use xdg-open if it possible
  * HTML-files openning fixed
  * firefox & chromium detection added
* Wed Mar 21 2012 subchaser1@gmail.com
- Update to 4.8.1.1. Major changes is:
  * License version updated to GPL3+ (#1551)
  * Configuration files was moved from your $HOME/.mc directory into
    XDG_CONFIG_* directories to respect FDO standard
  * VFS structure and paths is changed
  * keybinding names was renamed to provide some unification
  The changes since 4.7.5 are to numerous to list here.
  Please see the file NEWS in the documentation for a complete list.
- an CMake language syntax highlighting for mcedit added
- added .torrent extension
- use meadiainfo (if exists) to view multimemedia files
* Fri Feb  3 2012 dlovasko@suse.com
- Fixed rpmlint warning - added -fpie and -pie to compilation and linking of consaver
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Aug 11 2011 vladspbru@gmail.com
- update to 4.7.5.3
  * numerous changes and enhancements, see
    /usr/share/doc/packages/mc/NEWS
* Mon Apr 25 2011 lazy.kent@opensuse.org
- Don't convert Russian and Ukrainian docs. They have been already
  in UTF-8 (bnc#686483).
- Install help and hints for non-english locales (bnc#681060).
* Wed Mar 23 2011 pcerny@novell.com
- keep english version of help and hints in the main package
* Wed Feb  9 2011 vcizek@novell.com
- update to 4.7.5.1
  * numerous changes and enhancements, see
    /usr/share/doc/packages/mc/NEWS
* Wed Dec 29 2010 aj@suse.de
- Delete be@tarask translation.
* Tue Sep 14 2010 pth@suse.de
- Fix wrapper script for sh, change Makefile to substitute
  datadir (bnc#639044).
- Update to 4.7.0.9. Changes since 4.7.0.7:
  * Translation updates.
  * Added Galician translation.
  * Fix potential division by zero in Info panel.
  * Regexp replace only transforms the first occurence correctly.
  * Fix remaining plain int types in VFS.
  * Add "Toggle syntax highlighting" menu item.
  * Fix restoring of signals even if fork() fails.
  * Fix Segfault in replacement confirmation in editor.
* Thu Sep  9 2010 aj@suse.de
- BuildRequire gpm-devel
* Wed Sep  8 2010 pth@novell.com
- Add missing changes entry.
- Update to 4.7.0.7. The changes since 4.6.2 are to numerous to
  list here. Please see the file NEWS in the documentation for
  a complete list.
- Remove unneeded patches.
* Tue Jul 13 2010 pth@suse.de
- Fix pointer <-> int casts.
- Install x11_browser to _datadir/mc.
* Thu Mar 18 2010 prusnak@suse.cz
- little cleanup
* Sun Oct 11 2009 mseben@novell.com
- added mc-mkdir_mc_home.patch - create .mc home dir at startup (bnc#533262)
* Mon Jul 13 2009 coolo@novell.com
- only things that can be split into bundles can go into -lang
- do not require but recommend the -lang package
* Wed May 20 2009 nadvornik@suse.cz
- really apply 05_add_lzma_xz_support.patch
* Wed May  6 2009 nadvornik@suse.cz
- fixed crash in utf-8 patch [bnc#500516]
- allow to specify port number in the shell link [bnc#483249]
* Thu Mar 12 2009 prusnak@suse.cz
- added xz support (05_add_lzma_xz_support.patch)
* Wed Feb 25 2009 sbrabec@suse.cz
- Fixed Esc + Numeral F-key emulation (mc#287).
- Convert Serbian files to UTF-8.
- UTF-8 conversion moved to %%prep.
- Locale specific files moved to -lang package.
* Thu Feb 12 2009 nadvornik@suse.cz
- updated to final 4.6.2:
  * many patches mentioned bellow were included upstream
* Thu Nov 27 2008 nadvornik@suse.cz
- added desktop file [bnc#434809]
* Thu Oct  9 2008 nadvornik@suse.cz
- fixed dynamic loading of X11 library
  [http://savannah.gnu.org/bugs/index.php?24505]
* Tue Sep  9 2008 nadvornik@suse.cz
- added bugfixes from upstream cvs and from debian package for
  * preserve Attributes checkbox [bnc#419832]
  * fish filesystem [bnc#400515]
  * regexp matching
  * lzma support [bnc#400388]
  * other fixes and improvements
- fixed information displayed for rpm files [bnc#410704]
- partialy fixed SHIFT-Fn key behavior [bnc#400552]
* Mon Mar 31 2008 nadvornik@suse.cz
- fixed cursor appearance on visible tabs
* Mon Nov  5 2007 nadvornik@suse.cz
- updated to 4.6.2-pre1
  * improved subshell handling
  * improved fish filesystem
  * a lot of other fixes and enhancements
- updated UTF-8 patches using Fedora package
- added support for weak rpm dependencies in VFS
* Tue Aug 28 2007 nadvornik@suse.cz
- link duplicate files only inside /usr [#304167]
* Sat Aug 11 2007 olh@suse.de
- remove umode_t checks
  use offsetof() in vfs-impl.h
  build parallel
  move iconv updates to build section to fix quilt setup -v *.spec
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Tue Jul 17 2007 nadvornik@suse.cz
- fixed terminal escape sequences parsing (#253401)
* Mon Apr  2 2007 rguenther@suse.de
- add gpm BuildRequires
* Mon Jan 15 2007 nadvornik@suse.cz
- fixed special characters quoting for bash 3.2 [#232411]
* Wed Oct  4 2006 nadvornik@suse.cz
- built with --with-samba [#207643]
- fixed displaying of nlink column in utf8 mode [#194715]
- spec file cleanup [#194392]
* Wed Jun  7 2006 nadvornik@suse.cz
- fixes for Slang2 [#177920, #176327]
* Tue Apr 18 2006 schwab@suse.de
- Revert last change, kernel headers have been fixed.
* Tue Apr 18 2006 nadvornik@suse.cz
- fixed check for umode_t; it fixes compilation on ppc64
* Fri Apr  7 2006 lmichnovic@suse.cz
- adjusted ogg file opening (updated apps.patch)
* Mon Mar 13 2006 nadvornik@suse.cz
- make sure that backgrounded applications do not write
  to terminal [#153178]
- use realplay if available
- recognize .hpp files
* Tue Mar  7 2006 lmichnovic@suse.cz
- fixed bash specific syntax in /etc/profile.d/mc.sh [#155644]
  (updated wrapper.patch)
- changed default application to open images with from xv to display
  (updated apps.patch)
* Thu Feb  9 2006 nadvornik@suse.cz
- fixed switching long panels [143265]
- fixed crash on error in getpwuid
* Tue Feb  7 2006 ro@suse.de
- fix build for < 10.1
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 nadvornik@suse.cz
- used exported bash function in mc wrapper [#127769]
- fixed crash during renaming UTF-8 filenames [#131997]
* Thu Jan 12 2006 nadvornik@suse.cz
- compile with -fstack-protector
* Wed Oct 12 2005 nadvornik@suse.cz
- added patch for slang2
* Wed Aug 10 2005 nadvornik@suse.cz
- added .tbz2 and .djvu extension [fixes #98447]
* Mon Aug  1 2005 nadvornik@suse.cz
- updated to final 4.6.1
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Mon Mar  7 2005 nadvornik@suse.cz
- updated external applications
* Mon Jan 24 2005 meissner@suse.de
- 0 -> NULL in one glib call.
* Fri Jan 21 2005 nadvornik@suse.cz
- updated to 4.6.1-pre3
* Fri Nov 12 2004 ro@suse.de
- correct permissions handling for /usr/lib/mc/cons.saver
* Sat Oct 23 2004 mmj@suse.de
- rename no til nb
* Fri Sep 10 2004 nadvornik@suse.cz
- fixed quoting in extfs script CAN-2004-0494 [#43151]
- fixed show_output_starts_shell option [#44777]
- fixed mcedit crash [#43178]
* Wed Jun 30 2004 nadvornik@suse.cz
- many fixes in UTF8 patches
- fixed freeze on rar archives with password [#41591]
- allow large screen size [#41475]
* Fri Apr 23 2004 nadvornik@suse.cz
- fixed various buffer overflows and temp file handling [#38577]
- fixed crash on broken UTF-8 characters in directory name [#39309]
* Wed Mar 31 2004 nadvornik@suse.cz
- fixed sort options in mc-posix_options.diff
* Wed Mar 31 2004 nadvornik@suse.cz
- do not strip UTF-8 characters from prompt and xterm title [#37542]
* Thu Mar 25 2004 nadvornik@suse.cz
- fixed crash with NULL return from getpwuid [#36867]
* Thu Mar 18 2004 nadvornik@suse.cz
- fixed another crash in slang
* Mon Mar 15 2004 nadvornik@suse.cz
- fixed external applications
* Thu Mar 11 2004 nadvornik@suse.cz
- better fix for the crash is slang
- various fixes in utf8 patch
* Tue Mar  9 2004 nadvornik@suse.cz
- fixed crash if TERM is unset
- fixed viewing files in tar archives
* Mon Mar  8 2004 nadvornik@suse.cz
- fixed forward/backward word functions in utf8 patch
* Fri Mar  5 2004 nadvornik@suse.cz
- fixes in utf8 patches
- do not let XOpenDisplay exit [#31960]
* Mon Mar  1 2004 nadvornik@suse.cz
- added utf8 support in commandline, viewer and editor
* Wed Feb 18 2004 sbrabec@suse.cz
- Added all available UTF-8 patches (mostly from from Jakub Jelinek
  <jakub@redhat.com>).
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Jan  8 2004 pthomas@suse.de
- Fix the handling of symlinks inside tarballs which would lead
  to a segfault with suitably constructed tarballs.
* Fri Aug 29 2003 pthomas@suse.de
- Change extfs commands to use posix conforming options
  for head and sort. (#29657)
* Tue Jul 15 2003 sbrabec@suse.cz
- Autoreconf with GNOME prefix.
* Fri Jun 13 2003 kukuk@suse.de
- Fix filelist
* Fri Apr  4 2003 pthomas@suse.de
- Enable character set conversion by compiling with
  - -enable-charset.
* Wed Feb 26 2003 pthomas@suse.de
- Fix the bug that leads to a segfault when viewing
  files and simplify the range check.
- Get rid of the caddr_t anachronism.
- Use g_try_malloc when using glib2, as g_malloc terminates
  the application when it fails .....
* Mon Feb 17 2003 pthomas@suse.de
- Update to 4.6.0 which officially removes gmc.
- Get rid of now obsolete patches and adapt those that
  still apply.
* Tue Feb  4 2003 pthomas@suse.de
- Only include %%{_libdir}/mc in files on biarch platforms.
* Mon Jan 27 2003 pthomas@suse.de
- Drop gmc sub package.
- Also check for ksh in mc.sh to decide whether or not to use
  'export -f'
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
- changed neededforbuild <sp> to <opensp>
- changed neededforbuild <sp-devel> to <>
* Wed Oct 23 2002 sbrabec@suse.cz
- Fixed dangling symlink for mcview.
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Mon Sep 16 2002 pthomas@suse.de
- Make mc use the system supplied slang library.
* Wed Sep 11 2002 pthomas@suse.de
- Make full eight bits input the default (bug #15721).
- Use the gnome macros supplied with gnome-common.
- Use file type rather then regex to identify Word documents.
- Use wvText instead of word2x for displaying MS Word documents.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Fri Aug  2 2002 pthomas@suse.de
- Fix building with older versions of ext2fs lib
  (AKA older distributions):
  - Make configure check for presence of ext2_ino_t in ext2fs.h.
  - Use test result in vfs/undelfs.c
* Sat Jul 27 2002 adrian@suse.de
- fix %%pre script and neededforbuild
* Fri May 31 2002 ro@suse.de
- changed neededforbuild <slang> to <slang slang-devel>
* Mon Apr  8 2002 ro@suse.de
- run gettextize
* Fri Mar 15 2002 pthomas@suse.de
- Use w3m instead of lynx for html. Fixes #15012
* Thu Feb  7 2002 mmj@suse.de
- ... and then fix a stupid typo in the below fix...
* Thu Feb  7 2002 mmj@suse.de
- Fixed the below thing in a more POSIX compliant way
* Tue Feb  5 2002 mmj@suse.de
- Added missing function to ms.sh
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 okir@suse.de
- fixed various tempfile races (mostly with unpacking/packing
  of compressed files for editing)
* Mon Jan 14 2002 egmont@suselinux.hu
- Removed rpmview patch, no longer needed since 4.5.55.
* Thu Dec  6 2001 pthomas@suse.de
- Include *all* gnome autoconf macros needed to
  rebuild aclocal.m4.
* Fri Nov 30 2001 ro@suse.de
- changed neededforbuild <docbktls> to <docbook-toys>
* Mon Nov 26 2001 pthomas@suse.de
- Update to 4.5.55.
- Enable large file support.
- Gracefully handle the case when file size exceeds what
  g_malloc can handle.
- Don't hard-code the GUI web browser but call a script that
  uses whatever's installed.
- Use ext2_ino_t instead of ino_t.
- Add German hints.
* Thu Oct 18 2001 egmont@suselinux.hu
- F3 on an RPM shows sane output (kind of rpm -qilp) instead of raw
  binary.
* Thu Sep 20 2001 pthomas@suse.de
- Fix handling of RPMs. This isn't a final fix,  but at least
  avoids the error.
* Tue Sep  4 2001 kukuk@suse.de
- Removed smbclnt requires
* Mon Aug 27 2001 kukuk@suse.de
- Removed samba-client, not need any longer
* Mon Aug 27 2001 ro@suse.de
- replaced <smbclnt> by <samba-client> in neededforbuild
* Wed Aug 15 2001 pthomas@suse.de
- Redo declaration fixes.
- Drop samba support, it's dependencies cause too much trouble.
- Reduce compiler warnings.
- Require autoconf 2.53 as this allows use of AC_CHECK_DECLS
- Use AC_CHECK_DECLS to properly control local prototypes.
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Sat Aug 11 2001 schwab@suse.de
- Fix missing declarations *again*.
* Tue Jul 31 2001 cstein@suse.de
- wrote an assembly language syntax highlighting for mcedit
  (Intel syntax)
* Sat Jul  7 2001 egger@suse.de
- Updated to version 4.5.54.
- Had to remove a few patches to make it build.
- Buildproofed on all architectures.
* Wed Jun 27 2001 cstein@suse.de
- Modified mc to include some helpful functions for palm pilot
  users; modifications added as patch 30 (see spec file)
* Mon Jun 11 2001 pthomas@suse.de
- Create missing stamp-h.in that prevented mc to build.
- Don't use --with-gpm-mouse on s390
* Sat May 12 2001 schwab@suse.de
- Fix missing declarations.
* Wed May  9 2001 pthomas@suse.de
- remove samba codepages and require smbclnt.
  Fixes Bug #7924
- compress sources with bzip2
* Tue May  8 2001 pthomas@suse.de
- Include codepages from samba package and modify source to
  search them in /usr/lib/mc/codepages. Fixes bug #7647
* Fri Apr 20 2001 pthomas@suse.de
- Fix call of suse_update_config macro.
- Remove offending multibyte sequence from Korean message
  catalog and reenable building it.
* Wed Apr 18 2001 pthomas@suse.de
- Disable building of the korean message catalog because
  gettext 0.10.36 rejects it.
* Sat Apr  7 2001 schwab@suse.de
- Correct handling of filenames in zoo and zip files.
  Fixes Bug #6846.
- Add %%suse_update_config.
- Fix configure check for off64_t and ino64_t.
* Sat Apr  7 2001 pthomas@suse.de
- Remove regex match for *,[Dd]oc files and just rely on the
  file type check. Add a second file type check as file(1) now
  reports 'Microsoft office document'. Fixes Bug #6861
* Tue Mar 27 2001 ro@suse.de
- changed neededforbuild <docbkdsl> to <docbook-dsssl-stylesheets>
* Tue Mar 20 2001 pthomas@suse.de
- Compile with samba and ext2 undelete support
- Add esound-devel and e2fsprogs-devel to neededforbuild
- Remove unnecessary checks from samba configure
- Add security fix for subshell
- Add security fix for cons.saver
* Tue Mar 13 2001 ro@suse.de
- added xf86 to neededforbuild
* Tue Mar 13 2001 ro@suse.de
- changed neededforbuild <docbk30> to <docbook_3>
* Sun Feb 25 2001 egger@suse.de
- Remove unnecessary dependencies from #neededforbuild,
  especially imlib-config.
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Tue Feb 20 2001 uli@suse.de
- fixed for new glibc
* Tue Jan 30 2001 ro@suse.de
- changed neededforbuild <imlibcfe> to <imlib-config>
* Sun Jan 21 2001 violiet@suse.de
- added eightbit-clean.patch to view/edit for Japanese and
  Korean characters.
- added improvement Japanese latest .po from CVS.
- added improvement Korean .po and mc hint message file.
* Fri Dec 15 2000 hhetter@suse.de
- fix for dead link on startup-links, fixing bug id#4700
- changed startup-link URLs
* Tue Nov 21 2000 werner@suse.de
- Add kvt and gnome as valid TERMinals
- Add some newer xterm escape sequences (oldFunctionsKeys)
- console, linux xterm-color, kvt, and gnome are colored TERMinals
* Mon Nov  6 2000 pthomas@suse.de
- Remove version number from spec file name
- Add additional key definitions for mc.lib
- Clean up the spec file a bit.
* Sun Nov  5 2000 kukuk@suse.de
- adjust neededforbuild
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Mon Sep 25 2000 egger@suse.de
- Updated to 4.5.51.
- Buildproofed on i386.
* Tue May 30 2000 baulig@suse.de
- update: 4.5.50.
* Sun May 28 2000 baulig@suse.de
- update: 4.5.49.
- use %%{ver} instead of the direct version number in tarball name.
* Mon Dec 13 1999 ke@suse.de
- update: 4.5.42.
* Thu Nov 18 1999 ke@suse.de
- update: 4.5.41.
- create HTML documentation (add SGML packages to neededfoarbuild...).
- add SuSE startup-link ;)
* Fri Oct 29 1999 ke@suse.de
- fix /etc/opt/gnome vs. /opt/gnome/etc.
* Thu Oct 14 1999 ke@suse.de
- update: 4.5.40.
- add some RH patches.
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Fri Sep 24 1999 ke@suse.de
- update: version 4.5.39.
* Fri Sep 17 1999 ke@suse.de
- update: version 4.5.38.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul 15 1999 ke@suse.de
- update: version 4.5.37.
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Mon Jul 12 1999 ke@suse.de
- update: version 4.5.36.
* Tue Jun  8 1999 kukuk@suse.de
- Add pam to needforbuild
* Sun May 30 1999 ke@suse.de
- update: version 4.5.33.
* Tue Apr 13 1999 ke@suse.de
- update: version 4.5.30 (security fixes - /tmp exploids...).
* Tue Apr  6 1999 ro@suse.de
- only link gmc.gnorba for /etc/opt/gnome/CORBA/servers
* Mon Apr  5 1999 bs@suse.de
- fixed date strings in .changes.
* Mon Apr  5 1999 bs@suse.de
- use absolute links to prevent problems with a symlinked /opt.
* Sun Mar 14 1999 ke@suse.de
- update: version 4.5.25.
* Wed Mar 10 1999 ke@suse.de
- update: version 4.5.24.
* Thu Mar  4 1999 ke@suse.de
- update: version 4.5.23 (bugfix release).
- filelist.
* Sat Feb 27 1999 ke@suse.de
- update: version 4.5.22 (bugfix release).
* Fri Feb 26 1999 ke@suse.de
- update: version 4.5.21 (bugfix release).
- --disable-nls (it makes mc segfault).
- now, the text oriented part of the package (mc.rpm) lives under /usr
  again.
* Wed Feb 17 1999 ke@suse.de
- update: version 4.5.17 (bugfix release).
- use sysconfdir=/etc/opt/gnome.
- #neededforbuild: add esound and audiofil.
* Sun Feb 14 1999 ke@suse.de
- update: version 4.5.14 (bugfix release).
* Thu Feb 11 1999 ke@suse.de
- update: version 4.5.13.
* Sat Feb  6 1999 ro@suse.de
- fixed neededforbuild
* Thu Feb  4 1999 ke@suse.de
- update: version 4.5.10.
- now, there's the subpackage `gmc' containing the GNOME compliant version
  of mc.
- make the package BuildRoot capable.
* Wed Dec  9 1998 ke@suse.de
- update to mc 4.1.36 (bugfix release).
* Thu Sep 24 1998 ke@suse.de
- enable NLS.
- install documentation and COPYING via the %%doc macro.
* Tue Sep 22 1998 ro@suse.de
- update to mc 4.1.35 using diff from jurix mirror
  merged changes to mc.lib from mc-4.1.11-suse and current (+ibmpc3)
* Wed Nov 19 1997 florian@suse.de
- update to mc 4.1.11
* Sun Nov 16 1997 florian@suse.de
- oops, forgot mc.lib-changes from Werner
* Fri Oct 10 1997 florian@suse.de
- update to version 4.1.4
* Sun Jun 22 1997 florian@suse.de
- update to version 4.0
* Wed May 28 1997 werner@suse.de
- new mc.lib added
* Wed Jan 22 1997 florian@suse.de
- enable gpm support
* Thu Jan  2 1997 florian@suse.de
- update to version 3.2.11
* Thu Jan  2 1997 florian@suse.de
- Es wird nicht mehr mit libgpm-Unterstuetzung kompiliert, da slang
  und libgpm sich nicht vertragen. (libgpm laed libncurses, das geht
  mit libslang.a nicht...)
* Thu Jan  2 1997 florian@suse.de
- new version 3.2.7
- for screen output, mc now uses the slang library and not the ncurses functions
  directly
